Learn R Programming

MOM (version 0.1.0)

chisq_est: Method of Moments Estimation of Chi-Square distribution

Description

function to get the method of moment estimate(s) of chi-square distribution

Usage

chisq_est(data, plot = TRUE, curvecol = "red", ...)

Value

the estimated degree of freedom by the method of moments of the data assuming the underlying distribution is chi square distribution

Arguments

data

A numeric vector.

plot

logical which controls whether the histogram of the data along with the density curve of the theoretical chi square distribution with the estimated parameters.

curvecol

color of the theoretical density curve

...

additional plotting parameters

Examples

Run this code
chisq_est(rchisq(1000,df=3))

Run the code above in your browser using DataLab