Learn R Programming

MOM (version 0.1.0)

gamma_est: Method of Moments Estimation of Gamma distribution

Description

function to get the method of moment estimate(s) of gamma distribution

Usage

gamma_est(
  data,
  unknown = c("shape", "scale", "both"),
  shape = NULL,
  scale = NULL,
  plot = TRUE,
  curvecol = "red",
  ...
)

Value

the estimated parameters by the method of moments of the data assuming the underlying distribution is gamma distribution

Arguments

data

A numeric vector.

unknown

A character string specifying which parameter is (are) unknown to the user.

shape, scale

positive shape and scale parameters of the gamma distribution.

plot

logical which controls whether the histogram of the data along with the density curve of the theoretical gamma distribution with the estimated parameters.

curvecol

color of the theoretical density curve

...

additional plotting parameters

Examples

Run this code
gamma_est(rgamma(1000,shape=2,scale=1),unknown="scale",shape=2)#shape is known
gamma_est(rgamma(1000,shape=2,scale=1),unknown="shape",scale=1)#scale is known
gamma_est(rgamma(1000,shape=2,scale=1),unknown="both")#both will be estimated

Run the code above in your browser using DataLab