Learn R Programming

MOM (version 0.1.0)

geom_est: Method of Moments Estimation of Negative Binomial distribution

Description

function to get the method of moment estimate(s) of negative binomial distribution

Usage

geom_est(data, plot = TRUE, curvecol = "red", ...)

Value

the estimated parameters by the method of moments of the data assuming the underlying distribution is geometric distribution

Arguments

data

A numeric vector.

plot

logical which controls whether the barplot of the data along with the probability curve of the theoretical negative binomial distribution with the estimated parameters.

curvecol

color of the theoretical probability curve

...

additional plotting parameters

Examples

Run this code
geom_est(rgeom(1000,prob=0.2))

Run the code above in your browser using DataLab