the estimated degree of freedom by the method of moments of the data assuming the underlying distribution is chi square distribution
Arguments
data
A numeric vector.
plot
logical which controls whether the histogram of the data along with the density curve of the theoretical chi square distribution with the estimated parameters.