the estimated parameters by the method of moments of the data assuming the underlying distribution is geometric distribution
Arguments
data
A numeric vector.
plot
logical which controls whether the barplot of the data along with the probability curve of the theoretical negative binomial distribution with the estimated parameters.